@@ -7,7 +7,7 @@ RDF::Trine::Parser::NTriples - N-Triples Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::NTriples version 0.127
+This document describes RDF::Trine::Parser::NTriples version 0.128
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.127';
+	$VERSION	= '0.128';
 	$RDF::Trine::Parser::parser_names{ 'ntriples' }	= __PACKAGE__;
 	foreach my $type (qw(text/plain)) {
 		$RDF::Trine::Parser::media_types{ $type }	= __PACKAGE__;
@@ -150,7 +150,7 @@ sub _emit_statement {
 			if ($nodes->[2]->isa('RDF::Trine::Node::Literal') and $nodes->[2]->has_datatype) {
 				my $value	= $nodes->[2]->literal_value;
 				my $dt		= $nodes->[2]->literal_datatype;
-				my $canon	= $self->canonicalize_literal_value( $value, $dt );
+				my $canon	= RDF::Trine::Node::Literal->canonicalize_literal_value( $value, $dt, 1 );
 				$nodes->[2]	= literal( $canon, undef, $dt );
 			}
 		}
