@@ -3,11 +3,11 @@
 
 =head1 NAME
 
-RDF::Trine::Parser::Redland - RDF Parser using the Redland library
+RDF::Trine::Parser::Redland - RDFa Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::Redland version 0.999_02
+This document describes RDF::Trine::Parser::RDFa version 0.128
 
 =head1 SYNOPSIS
 
@@ -24,9 +24,6 @@ This document describes RDF::Trine::Parser::Redland version 0.999_02
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Trine::Parser> class.
-
 =over 4
 
 =cut
@@ -53,54 +50,29 @@ use RDF::Trine::Error qw(:try);
 our ($VERSION, $HAVE_REDLAND_PARSER, %FORMATS);
 BEGIN {
 	%FORMATS = (
-	rdfxml	 => [
-					'RDF::Trine::Parser::Redland::RDFXML',
-					'http://www.w3.org/ns/formats/RDF_XML',
-					[qw(application/rdf+xml)],
-					[qw(rdf xrdf rdfx)]
-				],
-	ntriples => [
-					'RDF::Trine::Parser::Redland::NTriples',
-					'http://www.w3.org/ns/formats/data/N-Triples',
-					[qw(text/plain)],
-					[qw(nt)]
-				],
-	turtle	 => [
-					'RDF::Trine::Parser::Redland::Turtle',
-					'http://www.w3.org/ns/formats/Turtle',
-					[qw(application/x-turtle application/turtle text/turtle)],
-					[qw(ttl)]
-				],
-	trig	 => [
-					'RDF::Trine::Parser::Redland::Trig',
-					undef,
-					[],
-					[qw(trig)]
-				],
-	librdfa	 => [
-					'RDF::Trine::Parser::Redland::RDFa',
-					'http://www.w3.org/ns/formats/data/RDFa',
-					[], #[qw(application/xhtml+xml)],
-					[], #[qw(html xhtml)]
-				],
+	rdfxml	 => ['http://www.w3.org/ns/formats/RDF_XML',
+					[qw(application/rdf+xml)]],
+	ntriples => ['http://www.w3.org/ns/formats/data/N-Triples',
+					[qw(text/plain)]],
+	turtle	 => ['http://www.w3.org/ns/formats/Turtle',
+					 [qw(application/x-turtle application/turtle text/turtle)]],
+	trig	 => [undef, []],
+	rdfa	 => ['http://www.w3.org/ns/formats/data/RDFa',
+					 [qw(application/xhtml+xml)]]
 	);
 	
-	$VERSION	= '0.999_02';
+	$VERSION	= '0.128';
 	for my $format (keys %FORMATS) {
-		$RDF::Trine::Parser::parser_names{$format} = $FORMATS{$format}[0];
-		$RDF::Trine::Parser::format_uris{ $FORMATS{$format}[1] } = $FORMATS{$format}[0]
-			if defined $FORMATS{$format}[1];
-		map { $RDF::Trine::Parser::media_types{$_} = $FORMATS{$format}[0] }
-			(@{$FORMATS{$format}[2]});
-		map { $RDF::Trine::Parser::file_extensions{$_} = $FORMATS{$format}[0] }
-			(@{$FORMATS{$format}[3]});
+		$RDF::Trine::Parser::parser_names{$format} = __PACKAGE__;
+		$RDF::Trine::Parser::format_uris{ $FORMATS{$format}[0] } = __PACKAGE__
+			if defined $FORMATS{$format}[0];
+		map { $RDF::Trine::Parser::media_types{$_} = __PACKAGE__ }
+			(@{$FORMATS{$format}[1]});
 	}
 	
-	unless ($ENV{RDFTRINE_NO_REDLAND}) {
-		eval "use RDF::Redland 1.000701;";
-		unless ($@) {
-			$HAVE_REDLAND_PARSER	= 1;
-		}
+	eval "use RDF::Redland 1.000701;";
+	unless ($@) {
+		$HAVE_REDLAND_PARSER	= 1;
 	}
 }
 
@@ -156,9 +128,6 @@ sub parse {
 	my $handler = shift;
 	
 	my $null_base	= 'urn:uuid:1d1e755d-c622-4610-bae8-40261157687b';
-	if ($base and blessed($base) and $base->isa('URI')) {
-		$base	= $base->as_string;
-	}
 	$base		= RDF::Redland::URI->new(defined $base ? $base : $null_base);
 	my $stream	= eval {
 		$self->{parser}->parse_string_as_stream($string, $base)
@@ -189,46 +158,8 @@ sub parse {
 
 		$stream->next;
 	}
-	
-	if (my $map = $self->{ namespaces }) {
-		my %seen	= $self->{parser}->namespaces_seen;
-		while (my ($ns, $uri) = each(%seen)) {
-			$map->add_mapping( $ns => $uri->as_string );
-		}
-	}
-	return;
 }
 
-package RDF::Trine::Parser::Redland::RDFXML;
-use strict;
-use warnings;
-use base qw(RDF::Trine::Parser::Redland);
-sub new { shift->SUPER::new( @_, name => 'rdfxml' ) }
-
-package RDF::Trine::Parser::Redland::NTriples;
-use strict;
-use warnings;
-use base qw(RDF::Trine::Parser::Redland);
-sub new { shift->SUPER::new( @_, name => 'ntriples' ) }
-
-package RDF::Trine::Parser::Redland::Turtle;
-use strict;
-use warnings;
-use base qw(RDF::Trine::Parser::Redland);
-sub new { shift->SUPER::new( @_, name => 'turtle' ) }
-
-package RDF::Trine::Parser::Redland::Trig;
-use strict;
-use warnings;
-use base qw(RDF::Trine::Parser::Redland);
-sub new { shift->SUPER::new( @_, name => 'trig' ) }
-
-package RDF::Trine::Parser::Redland::RDFa;
-use strict;
-use warnings;
-use base qw(RDF::Trine::Parser::Redland);
-sub new { shift->SUPER::new( @_, name => 'librdfa' ) }
-
 
 1;
 
@@ -236,22 +167,13 @@ __END__
 
 =back
 
-=head1 ENVIRONMENT VARIABLES
-
-Set C<RDFTRINE_NO_REDLAND> to something true to disable the Redland parsers.
-
-=head1 BUGS
-
-Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/perlrdf/issues>.
-
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2006-2010 Gregory Todd Williams. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
