@@ -7,7 +7,7 @@ RDF::Trine::Parser::TriG - TriG RDF Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::TriG version 0.127
+This document describes RDF::Trine::Parser::TriG version 0.128
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,7 @@ use RDF::Trine qw(literal);
 
 our ($VERSION);
 BEGIN {
-	$VERSION				= '0.127';
+	$VERSION				= '0.128';
 	$RDF::Trine::Parser::parser_names{ 'trig' }	= __PACKAGE__;
 # 	foreach my $type (qw(application/x-turtle application/turtle text/turtle)) {
 # 		$RDF::Trine::Parser::media_types{ $type }	= __PACKAGE__;
@@ -60,7 +60,7 @@ sub _triple {
 		if ($o->isa('RDF::Trine::Node::Literal') and $o->has_datatype) {
 			my $value	= $o->literal_value;
 			my $dt		= $o->literal_datatype;
-			my $canon	= $self->canonicalize_literal_value( $value, $dt );
+			my $canon	= RDF::Trine::Node::Literal->canonicalize_literal_value( $value, $dt, 1 );
 			$o	= literal( $canon, undef, $dt );
 		}
 	}
