@@ -7,7 +7,7 @@ RDF::Trine::Serializer - RDF Serializer class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer version 0.127
+This document describes RDF::Trine::Serializer version 0.128
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ our %serializer_names;
 our %format_uris;
 our %media_types;
 BEGIN {
-	$VERSION	= '0.127';
+	$VERSION	= '0.128';
 }
 
 use LWP::UserAgent;
@@ -51,6 +51,16 @@ use RDF::Trine::Serializer::Turtle;
 
 =over 4
 
+=item C<< serializer_names >>
+
+Returns a list of valid serializer names for use as arguments to the serializer constructor.
+
+=cut
+
+sub serializer_names {
+	return keys %serializer_names;
+}
+
 =item C<< new ( $serializer_name, %options ) >>
 
 Returns a new RDF::Trine::Serializer object for the serializer with the
